@@ -110,6 +110,7 @@ def download_project_async(mc, project_path, directory):
     os.makedirs(directory)
     mp = MerginProject(directory)
 
+    mp.log.info("--- version: " + mc.user_agent_info())
     mp.log.info(f"--- start download {project_path}")
 
     try:
@@ -236,6 +237,7 @@ class UpdateTask:
         basename = os.path.basename(self.file_path)   #file['diff']['path']) if diff_only else os.path.basename(file['path'])
         file_dir = os.path.dirname(os.path.normpath(os.path.join(directory, self.file_path)))
         dest_file_path = os.path.join(file_dir, basename)
+        os.makedirs(file_dir, exist_ok=True)
 
         # merge chunks together (and delete them afterwards)
         file_to_merge = FileToMerge(dest_file_path, self.download_queue_items)
@@ -320,6 +322,7 @@ def pull_project_async(mc, directory):
     project_path = mp.metadata["name"]
     local_version = mp.metadata["version"]
 
+    mp.log.info("--- version: " + mc.user_agent_info())
     mp.log.info(f"--- start pull {project_path}")
 
     server_info = mc.project_info(project_path, since=local_version)
@@ -370,6 +373,7 @@ def pull_project_async(mc, directory):
         file_dir = os.path.dirname(os.path.normpath(os.path.join(temp_dir, file['path'])))
         basename = os.path.basename(file['diff']['path']) if diff_only else os.path.basename(file['path'])
         dest_file_path = os.path.join(file_dir, basename)
+        os.makedirs(file_dir, exist_ok=True)
         files_to_merge.append( FileToMerge(dest_file_path, items) )
 
 
