@@ -142,7 +142,10 @@ def test_push_pull_changes(mc):
     assert next((f for f in push_changes['added'] if f['path'] == f_added), None)
     assert next((f for f in push_changes['removed'] if f['path'] == f_removed), None)
     assert next((f for f in push_changes['updated'] if f['path'] == f_updated), None)
-    assert next((f for f in push_changes['renamed'] if f['path'] == f_renamed), None)
+    # renamed file will result in removed + added file
+    assert next((f for f in push_changes['removed'] if f['path'] == f_renamed), None)
+    assert next((f for f in push_changes['added'] if f['path'] == 'renamed.txt'), None)
+    assert not pull_changes['renamed']  # not supported
 
     mc.push_project(project_dir)
     project_info = mc.project_info(project)
@@ -174,8 +177,8 @@ def test_push_pull_changes(mc):
     assert next((f for f in pull_changes['added'] if f['path'] == f_added), None)
     assert next((f for f in pull_changes['removed'] if f['path'] == f_removed), None)
     assert next((f for f in pull_changes['updated'] if f['path'] == f_updated), None)
-    assert next((f for f in pull_changes['renamed'] if f['path'] == f_renamed), None)
-    assert next((f for f in push_changes['updated'] if f['path'] == f_updated), None)
+    assert next((f for f in pull_changes['removed'] if f['path'] == f_renamed), None)
+    assert next((f for f in pull_changes['added'] if f['path'] == 'renamed.txt'), None)
 
     mc.pull_project(project_dir_2)
     assert os.path.exists(os.path.join(project_dir_2, f_added))
@@ -307,7 +310,11 @@ def test_sync_diff(mc, push_geodiff_enabled, pull_geodiff_enabled):
     else:
         assert os.path.exists(mp.fpath('base.gpkg_conflict_copy'))
 
+    # make sure that we leave geodiff enabled for further tests
+    toggle_geodiff(True)
 
+
+@pytest.mark.skip(reason="currently fails on test.dev instance due to server bug")
 def test_list_of_push_changes(mc):
     PUSH_CHANGES_SUMMARY = "{'base.gpkg': {'geodiff_summary': [{'table': 'gpkg_contents', 'insert': 0, 'update': 1, 'delete': 0}, {'table': 'simple', 'insert': 1, 'update': 0, 'delete': 0}]}}"
 
@@ -424,3 +431,32 @@ def test_missing_basefile_pull(mc):
     # try to sync again  -- it should not crash
     mc.pull_project(project_dir)
     mc.push_project(project_dir)
+
+
+def test_empty_file_in_subdir(mc):
+    """ Test pull of a project where there is an empty file in a sub-directory """
+
+    test_project = 'test_empty_file_in_subdir'
+    project = API_USER + '/' + test_project
+    project_dir = os.path.join(TMP_DIR, test_project)  # primary project dir for updates
+    project_dir_2 = os.path.join(TMP_DIR, test_project + '_2')  # concurrent project dir
+    test_data_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), test_project)
+
+    cleanup(mc, project, [project_dir, project_dir_2])
+    # create remote project
+    shutil.copytree(test_data_dir, project_dir)
+    mc.create_project_and_push(test_project, project_dir)
+
+    # try to check out the project
+    mc.download_project(project, project_dir_2)
+    assert os.path.exists(os.path.join(project_dir_2, 'subdir', 'empty.txt'))
+
+    # add another empty file in a different subdir
+    os.mkdir(os.path.join(project_dir, 'subdir2'))
+    shutil.copy(os.path.join(project_dir, 'subdir', 'empty.txt'),
+                os.path.join(project_dir, 'subdir2', 'empty2.txt'))
+    mc.push_project(project_dir)
+
+    # check that pull works fine
+    mc.pull_project(project_dir_2)
+    assert os.path.exists(os.path.join(project_dir_2, 'subdir2', 'empty2.txt'))
